from .animals import (
    cat_says,
    dog_says,
    frog_says,
    fox_says,
    cow_says,
    pig_says,
    owl_says,
    bat_says,
    dolphin_says,
    shark_says,
    elephant_says,
    bunny_says,
    spider_says,
    horse_says,
    monkey_says,
    wolf_says
)



from setuptools import setup, find_packages
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding="utf-8")

setup(
    name="animalssay",
    version="0.2.1",
    packages=find_packages(),
    author="hunter",
    description="A simple example Python library where animals can say words",
    long_description=long_description,
    long_description_content_type="text/markdown",
)
